#
# spec file for package python-pyfakefs
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor test%{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-pyfakefs%{psuffix}
Version:        5.8.0
Release:        2.1
Summary:        Fake file system that mocks the Python file system modules
License:        Apache-2.0
URL:            https://github.com/jmcgeheeiv/pyfakefs
Source:         https://github.com/jmcgeheeiv/pyfakefs/archive/v%{version}.tar.gz#/python-pyfakefs-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module pytest >= 3}
BuildRequires:  %{pythons}
%endif
%python_subpackages

%description
pyfakefs implements a fake file system that mocks the Python file system
modules. Using pyfakefs, your tests operate on a fake file system in
memory without touching the real disk. The software under test requires
no modification to work with pyfakefs.

%prep
%setup -q -n pyfakefs-%{version}

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand rm -r %{buildroot}%{$python_sitelib}/pyfakefs/tests/
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
export LANG=C.UTF-8
%python_expand PYTHONPATH=$(pwd) $python -m pyfakefs.tests.all_tests
%endif

%if !%{with test}
%files %{python_files}
%doc CHANGES.md README.md
%license COPYING
%{python_sitelib}/pyfakefs
%{python_sitelib}/pyfakefs-%{version}.dist-info
%endif

%changelog
* Wed Jun 11 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
* Mon Apr 28 2025 Dirk Müller <dmueller@suse.com>
- update to 5.8.0:
  * Adds preliminary support for Python 3.14.
  * added some preliminary support for Python 3.14
  * change behavior of `FakeFilesystem.get_object()` to ignore
    permissions as it has been
  * before version 5.4.0 (see #1122)
  * fixed a problem with flushing if writing over the buffer end
  * (see #1120)
  * fixed a regression that could break tests under Posix in
    Python 3.12
  * (see #1126)
  * fixed behavior for `os.access` for symlinks under Windows
  * fixed permission problem on querying file properties (see
    [#1122])
  * fixed patching in pytest setup phase for module and session-
    scoped fs fixtures
  * fixed a problem with module and session scoped fixtures in
    Python 3.13
  * fixed handling of `cwd` if set to a `pathlib.Path` (see
    [#1108])
  * fixed documentation for cleanup handlers, added convenience
    handler `reload_cleanup_handler`
  * Fixes some problems with patching.
  * added some support for loading fake modules in `AUTO` patch
    mode using `importlib.import_module` (see #1079)
  * added some support to avoid patching debugger related modules
  * avoid reloading `tempfile` in Posix systems
  * Adds official Python 3.13 support, improves OS emulation
    behavior.
  * avoid reloading `glob` in Python 3.13
  * removing files while iterating over `scandir` results is now
    possible (see #1051)
  * fake `pathlib.PosixPath` and `pathlib.WindowsPath` now behave
    more like in the real filesystem
  * (see #1053)
  * `PurePosixPath` reported Windows reserved names as reserved
    in Python >= 3.12
  * (see #1067)
  * `PurePosixPath.joinpath()` incorrectly handled paths with
    drives under Windows in Python >= 3.12
  * (see #1070)
* Fri Jul 26 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 5.6.0
  * added preliminary support for Python 3.13 (tested with beta2) (see #1017)
  * added `apply_umask` argument to `FakeFilesystem.create_dir`
    to allow ignoring the umask (see #1038)
  * use real open calls for remaining `pathlib` functions so that
    it works nice with skippedmodules (see #1012)
- from version 5.5.0
  * The usage of the `pathlib2` and `scandir` modules in pyfakefs
    is now deprecated. They will now cause deprecation warnings
    if still used. Support for patching these modules will be removed
    in pyfakefs 6.0.
  * `PureWindowsPath` and `PurePosixPath` now use filesystem-independent
    path separators, and their path-parsing behaviors are now consistent
    regardless of runtime platform and/or faked filesystem customization
    (see #1006)
  * fixed handling of Windows `pathlib` paths under POSIX and vice verse
    (see #1006)
  * correctly use real open calls in pathlib for skipped modules (see #1012)
* Sun Apr 21 2024 Dirk Müller <dmueller@suse.com>
- update to 5.4.1:
  * fixed a regression from version 5.4.0 that incorrectly
    handled files opened twice via file descriptor
- update to 5.4.0
  * Improves permission handling.
  * added support for `O_NOFOLLOW` and `O_DIRECTORY` flags in
    `os.open`
  * added support for fake `os.dup`, `os.dup2` and `os.lseek`
  * fixed a specific problem on reloading a pandas-related module
  * added possibility for unload hooks for specific modules
    use this also to reload django views (see #932)
  * fixed `EncodingWarning` for Python >= 3.11 (see #957)
    consider directory ownership while adding or removing
    directory entries
  * fixed handling of directory enumeration and search
    permissions under Posix systems
  * fixed creation of the temp directory in the fake file system
    after a filesystem reset
  * fixed handling of `dirfd` in `os.symlink` (see #968)
  * add missing `follow_symlink` argument to `os.link` (see #973)
  * fixed handling of missing attribute in `os.getxattr` (see
  * fixed permission problem with `shutil.rmtree` if emulating
    Windows under POSIX
  * fixed handling of errors on opening files via file descriptor
  * fixed handling of `umask` - it is now applied by default
  * fixed behavior of `os.makedirs` (see #987)
* Sun Feb  4 2024 Dirk Müller <dmueller@suse.com>
- update to 5.3.5:
  * Fixes a regression due to the changed behavior of the dynamic
    patcher cleanup (see #939).
  * The change is now by default only made if the `django` module
    is loaded, and the behavior can
  * be changed using the new argument `module_cleanup_mode`.
* Fri Jan 26 2024 Dirk Müller <dmueller@suse.com>
- update to 5.3.4:
  * fixes handling of unhashable modules which cannot be cached
    (see #923)
  * reload modules loaded by the dynamic patcher instead of
    removing them - sometimes they may
  * not be reloaded automatically (see #932)
  * add back argument `use_dynamic_patch` as a fallback for
    similar problems
  * fixed a problem with patching `_io` under Python 3.12 (see
    [#910])
  * fixed a problem with accessing the temp path if emulating
    Linux under Windows
  * (see #912)
  * fixed result of `os.walk` with a path-like top directory
  * (see #915)
  * properly fixed the problem that filesystem patching was still
    active in the pytest
  * logreport phase (see #904), the previous fix was incomplete
  * changed behavior of `add_real_directory` to be able to map a
    real directory
  * Restores compatibility with PyTorch 2.0 and above, as well as
    with other classes that have custom __setattr__ methods
    (see #905).
  * Adds official support for Python 3.12.
  * removed a leftover debug print statement (see #869)
  * make sure tests work without HOME environment set (see #870)
  * automount drive or UNC path under Windows if needed for
    `pathlib.Path.mkdir()`
  * (see #890)
  * adapt patching `io.open` and `io.open_code` to work with
    Python 3.12
  * (see #836 and #892)
* Thu Sep  7 2023 Dirk Müller <dmueller@suse.com>
- update to 5.2.4:
  * Fixes a rare problem on pytest shutdown.
  * Adds compatibility with PyPy 3.10 and Python 3.12.
* Wed May 10 2023 Dirk Müller <dmueller@suse.com>
- update to 5.2.2:
  * Made the user and group IDs accessible via dedicated
    ``get_uid`` and ``get_gid`` functions
    (for symmetry to ``set_uid`` / ``set_gid``)
  * The test fixture is now included in the source distribution
    and installed with the package.
  * Some public constants in `fake_filesystem` that had been
    moved to `helpers` are made accessible from there again
  * Add missing fake implementations for `os.getuid` and
    `os.getgid` (Posix only)
  * Make sure a `/tmp` path exists under linux (`TMPDIR` may
    point elsewhere)
  * Support for latest Python 3.12 version.
  * Properties defining the capabilities of some `os` functions
    like `os.supports_follow_symlinks` are now properly faked to
    contain the fake functions if the real functions are faked
  * Supports current Python 3.12 version (alpha 6). We plan to
    make patch releases in case of breaking changes in alpha
    or beta versions.
  * Fake module classes previously defined in `fake_filesystem`
    have now moved to their own modules: `fake_os.FakeOsModule`,
    `fake_path.FakePathModule`, `fake_io.FakeIoModule` and
    `fake_open.FakeFileOpen`.
  * Patching of parsers for pandas >= 1.2 is removed since pandas
    now uses Python fs functions internally even when the engine
    selected is "c".
  * added possibility to set a path inaccessible under Windows by
    using `chown()` with the `force_unix_mode` flag (see #720)
  * added class level setup method `setUpClassPyfakefs` for
    unittest and class-scoped
  * fixture `fs_class` for pytest (see #752)
  * added experimental support for Python 3.12: added fake APIs
    for Windows junction support. These are not implemented and
    always return `False`.
  * added Python 3.12 to the test suite.
  * migrated to setuptools declarative syntax.
  * fixed docker tests when running on branches containing
    forward slashes
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 5.0.0
  New version after the transfer to pytest-dev.
  Changes
  * the old-style API deprecated since version 3.4 has now been removed
  * the method copyRealFile deprecated since version 3.2 has been removed - use add_real_file instead
  Infrastructure
  * transferred the repository to the pytest-dev organization
  * renamed the master branch to main
  * added automatic PyPI release workflow
  * move documentation from GitHub Pages to Read the Docs
  New Features
  * added some support for st_blocks in stat result (see #722)
  Fixes
  * fixed handling of O_TMPFILE in os.open (caused handling of O_DIRECTORY as O_TMPFILE) (see #723)
  * fixed handling of read permissions (see #719)
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 4.7.0
  Changes
  fs fixtures cannot be nested; any nested fs fixture
  (for example inside an fs_session or fs_module fixture) will just reference the outer fixture (the behavior had been unexpected before)
  Fixes
  reverted a performance optimization introduced in version 3.3.0 that caused hanging tests with installed torch (see #693)
  do not use the build-in opener in pathlib as it may cause problems (see #697)
  add support for path-like objects in shutil.disk_usage (see #699)
  do not advertise support for Python 3.6 in setup.py (see #707)
  return the expected type from fcntl.ioctl and fcntl.fcntl calls if arg is of type byte; the call itself does nothing as before
  do not skip filesystem modules by name to allow using own modules with the same name (see #707)
  add missing support for os.renames (see #714)
* Fri Aug  5 2022 Ben Greiner <code@bnavigator.de>
- Update to 4.6.3
  * automatically reset filesystem on changing is_windows_fs or
    is_macos (see #692) - ensures better upwards compatibility in
    most cases
  * Make sure you write to the filesystem after you change
    is_windows_fs or is_macos, otherwise the changes will be lost.
  * fixed regression: os.path.exists returned True for any root
    drive path under Windows
- Update to 4.6.2
  * fixed support for opener introduced in previous patch release
    (see #689)
  * added support for opener argument in open, which is used in
    tempfile in Python 3.11 since beta 4 (see #686)
  * make sure tests run without pyfakefs installed as a package
    (see #687)
- Version 4.6.0
  * Adds support for Python 3.11, removes support for Python 3.6,
    changes root path behavior under Windows.
  * Python 3.6 has reached its end of life on 2021/12/23 and is no
    longer officially supported by pyfakefs ** os.stat_float_times
    has been removed in Python 3.7 and is therefore no longer
    supported under Windows, the root path is now effectively C:\
    instead of \; a path starting with \ points to the current
    drive as in the real file system (see #673)
  * fake pathlib.Path.owner() and pathlib.Path.group() now behave
    like the real methods - they look up the real user/group name
    for the user/group id that is associated with the fake file
    (see #678)
  * added some support for the upcoming Python version 3.11 (see
    [#677])
  * added convenience fixtures for module- and session based fs
    fixtures (fs_module and fs_session)
  * fixed an incompatibility of tmpdir (and probably other
    fixtures) with the module-scoped version of fs; had been
    introduced in pyfakefs 4.5.5 by the fix for #666 (see #684)
- Version 4.5.6
  * Fixes a regression which broke tests with older pytest versions
    (< 3.9).
  * minimum supported pytest version is now 3.0 (older versions do
    not work properly with current Python versions)
  * only skip _pytest.pathlib in pytest versions where it is
    actually present (see #669)
- Version 4.5.5
  * Bugfix release, needed for compatibility with pytest 7.0.
  * correctly handle file system space for files opened in write
    mode (see #660)
  * correctly handle reading/writing pipes via file (see #661)
  * disallow encoding argument on binary open() (see #664)
  * fixed compatibility issue with pytest 7.0.0 (see #666)
- Version 4.5.4
  * added missing mocked functions for fake pipe (see #650)
  * fixed some bytes warnings (see #651)
- Don't catchall in files section
* Tue Dec 14 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.5.3:
  * New Features
    + added support for some Python 3.10 features:
    + new method pathlib.Path.hardlink_to
    + new newline argument in pathlib.Path.write_text
    + new follow_symlinks argument in pathlib.Path.stat and pathlib.Path.chmod
    + new 'strict' argument in os.path.realpath
    + added support for pathlib.Path.link_to (new in Python 3.8) (see #580)
    + added support for pathlib.Path.readlink (new in Python 3.9) (see #584)
    + added FakeFilesystem.create_link convenience method which creates intermittent directories (see #580)
  * Changes
    + Python 3.5 has reached its end of life in September 2020 and is no longer supported
    + pathlib2 is still supported, but considered to have the same functionality as pathlib and is no longer tested separately; the previous behavior broke newer pathlib features if pathlib2 was installed (see #592)
    + Added caching of patched modules to avoid lookup overhead
    + Added use_cache option and clear_cache method to be able to deal with unwanted side effects of the newly introduced caching
    + The patchfs decorator now expects a positional argument instead of the keyword arguments fs. This avoids confusion with the pytest fs fixture and conforms to the behavior of mock.patch. You may have to adapt the argument order if you use the patchfs and mock.patch decorators together (see #566)
    + Default arguments that are file system functions are now not patched by default to avoid a large performance impact. An additional parameter patch_default_args has been added that switches this behavior on (see #567).
  * Fixes
    + added handling of path-like where missing
    + improved handling of str/bytes paths
    + suppress all warnings while inspecting loaded modules (see #614)
    + do not import pandas and related modules if it is not patched (see #627)
    + handle pathlib.Path.owner() and pathlib.Path.group by returning the current user/group name (see #629)
    + fixed handling of use_known_patches=False (could cause an exception)
    + correctly handle byte paths in os.path.exists (see #595)
    + Update fake_pathlib to support changes coming in Python 3.10 (see
    + correctly handle UNC paths in os.path.split and in directory path evaluation (see #606)
    + fixed handling of pipe descriptors in the fake filesystem (see #581)
    + added non-functional argument effective_ids to os.access (see #585)
    + correctly handle os.file for unreadable files (see #588)
    + Reverted one Windows-specific optimization that can break tests under some conditions (see #573)
    + Setting os did not reset os.sep and related variables, fixed null device name, added os.pathsep and missing os.path variables (see #572)
    + open calls had not been patched for modules with a name ending with "io" (see #569)
    + remove dependency of pyfakefs on pytest (regression, see #565)
* Sat Mar 14 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.0.2:
  * py3 only variant
* Sun Mar  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Swith to multibuild in order to avoid full python buildcycle
* Sat Mar  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.7.2:
  * Various fixes for python 3.8
* Wed Dec 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Pull in the full python
* Mon Oct  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update 3.6.1:
  * fix borked tests from 3.6
* Mon Oct  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.6:
  * fixed incorrect argument names for some os functions
  * fake DirEntry now implements os.PathLike in Python >= 3.6 (see #483)
  * fixed incorrect argument name for os.makedirs (see #481)
  * avoid pytest warning under Python 2.7 (see #466)
  * add next to FakeFileWrapper (see #485)
* Fri Mar 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.5.8:
  * Mainly fixes a regression bug under Python 2.7.
* Tue Feb 12 2019 Karol Babioch <kbabioch@suse.de>
- Update to version 3.5.7
  * Fixes a regression introduced in the last version
* Mon Jan 14 2019 Karol Babioch <kbabioch@suse.de>
- Removed unit tests from package
* Sun Jan 13 2019 Karol Babioch <kbabioch@suse.de>
- Update to version 3.5.6
  * import external pathlib2 and scandir packages first if present
* Thu Dec 20 2018 Karol Babioch <kbabioch@suse.de>
- Update to version 3.5.5
  * Removed permission warnings (shebang line vs. executable bit)
* Thu Dec 20 2018 Karol Babioch <kbabioch@suse.de>
- Update to version 3.5.4
  * added context manager class Pause for pause/resume
  * fixed permission handling for root user
  * avoid AttributeError triggered by modules without __module__ attribute
* Thu Nov 22 2018 Karol Babioch <kbabioch@suse.de>
- Update to version 3.5.3
  * automatically patch file system methods imported as another name like from
    os.path import exists as my_exists, including builtin open and io.open
  * make tests for access time less strict to account for file systems that do
    not change it immediately
* Mon Nov 12 2018 Karol Babioch <kbabioch@suse.com>
- Update to version 3.5.2
  * This is mostly a bug-fix release.
  * added support for pause/resume of patching the file system modules
  * allow to set current group ID, set current user ID and group ID as `st_uid`
    and `st_gid` in new files
  * fixed using `modules_to_patch` (regression)
  * fixed recursion error on unpickling the fake file system
  * allow trailing path in `add_real_directory`
* Thu Nov  1 2018 Tomáš Chvátal <tchvatal@suse.com>
- State in more dependencies, the tests are still borked
* Tue Oct 23 2018 Karol Babioch <kbabioch@suse.com>
- Update to version 3.5
  * This version of pyfakefs does not support Python 3.3.
  * The deprecation warnings for the old API are now switched on by default.
  * Improved automatic patching:
  * added possibility to set user ID
  * added side_effect option to fake files
  * added some support for extended filesystem attributes under Linux
  * handle `contents=None` in `create_file()` as empty contents if size not set
  * added pathlib2 support
  * added support for null device
  * improved error message for "Bad file descriptor in fake filesystem"
  * fixed pytest when both pyfakefs and future are installed
  * file timestamps are now updated more according to the real behavior
  * fixed a problem related with patching shutil functions using zipfile
* Thu Jun 14 2018 kbabioch@suse.com
- Update to version 3.4.3
  - Added support for path-like objects as arguments in create_file(),
    create_dir(), create_symlink(), add_real_file() and add_real_directory()
  - Bugfixes:
  - tell after seek gave incorrect result in append mode
  - flushing file contents after truncate was incorrect under some conditions
  - readline() did not work correctly in binary mode
  - pathlib.Path.resolve() behaved incorrectly if the path does not exist
  - closed attribute was not implemented in fake file
  - add_real_directory did not behave correctly for nested paths
  - several functions did not behave correctly for paths ending with a
    path separator
* Tue Apr 17 2018 kbabioch@suse.com
- Initial packaging of version 3.4.1
